@@ -287,13 +287,9 @@ class HandlerSocket(threading.local):
             raise OperationalError('HandlerSocket returned an error code: %s' % error)
 
         columns = int(tokens[1])
-        data_tokens = tokens[2:]
-        decoded_tokens = imap(decode, data_tokens)
+        decoded_tokens = imap(decode, tokens[2:])
         # Divide response tokens list by number of columns
-        if len(data_tokens) > 1:
-            data = zip(*[decoded_tokens]*columns)
-        else:
-            data = list(decoded_tokens)
+        data = zip(*[decoded_tokens]*columns)
 
         return data
 
@@ -397,7 +393,7 @@ class ReadSocket(HandlerSocket):
         :param integer index_id: id of opened index.
         :param string operation: logical comparison operation to use over ``columns``.
             Currently allowed operations are defined in :const:`~.FIND_OPERATIONS`.
-             Only one operation is allowed per call.
+            Only one operation is allowed per call.
         :param iterable columns: list of column values for comparison operation.
             List must be ordered in the same way as columns are defined
             in opened index.
@@ -431,7 +427,7 @@ class WriteSocket(HandlerSocket):
 
     def find_modify(self, index_id, operation, columns, modify_operation,
                     modify_columns=[], limit=0, offset=0):
-        """Updates/deletes row(s) using opened index,
+        """Updates/deletes row(s) using opened index.
 
         Returns number of modified rows or a list of original values in case
         ``modify_operation`` ends with ``?``.
